﻿namespace UltraDayViewLines
{
    using System.Drawing;
    using Infragistics.Win;
    using Infragistics.Win.UltraWinSchedule;
    using Infragistics.Win.UltraWinSchedule.DayView;

    internal class DF : IUIElementDrawFilter
    {
        private Pen minutesPen;
        private Pen hoursPen;

        public DF(Pen hoursPen, Pen minutesPen)
        {
            this.hoursPen = hoursPen;
            this.minutesPen = minutesPen;
        }

        public bool DrawElement(DrawPhase drawPhase, ref UIElementDrawParams drawParams)
        {
            //  Check if we are on the way to draw TimeSlotUIElement
            var timeSlotElement = drawParams.Element as TimeSlotUIElement;
            if(timeSlotElement != null)
            {
                //  Get the TimeSlot for this UIElement
                var timeSlot = timeSlotElement.GetContext() as TimeSlot;
                if(timeSlot != null)
                {
                    var rect = drawParams.Element.Rect;
                    var left = rect.Left;
                    var top = rect.Top - 1;
                    var right = rect.Right;

                    //  Draw a line at the top of the TimeSlotUIelement
                    if(timeSlot.StartTime.Minute == 0)
                        //  If the time slot is at the start of the hour use hour pen
                        drawParams.Graphics.DrawLine(this.hoursPen, left, top, right, top);
                    else
                        //  If the time slot is not at start of the hour use minutes pen
                        drawParams.Graphics.DrawLine(this.minutesPen, left, top, right, top);
                    return true;
                }
            }

            return false;
        }

        public DrawPhase GetPhasesToFilter(ref UIElementDrawParams drawParams)
        {
            if(drawParams.Element is TimeSlotUIElement)
            {
                return DrawPhase.BeforeDrawForeground;
            }

            return DrawPhase.None;
        }
    }
}

/* UIElements tree
 * 
 * UltraDayViewUIElement, Location = {X=0,Y=0,Width=429,Height=542}
    MainUIElement, Location = {X=0,Y=0,Width=410,Height=542}
        TopLeftAreaUIElement, Location = {X=0,Y=0,Width=67,Height=59}
        HeadingAreaUIElement, Location = {X=67,Y=0,Width=343,Height=59}
            DayHeaderAreaUIElement, Location = {X=67,Y=0,Width=343,Height=18}
                DayHeaderUIElement, Location = {X=68,Y=1,Width=341,Height=17}
                    TextUIElement, Location = {X=179,Y=1,Width=119,Height=17}
            AllDayEventAreaUIElement, Location = {X=67,Y=18,Width=343,Height=41}
                AllDayEventAreaDayUIElement, Location = {X=67,Y=18,Width=343,Height=41}
        DayAreaUIElement, Location = {X=67,Y=59,Width=343,Height=483}
            DayUIElement, Location = {X=67,Y=59,Width=343,Height=483}
                TimeSlotUIElement, Location = {X=67,Y=59,Width=343,Height=21}
                TimeSlotUIElement, Location = {X=67,Y=80,Width=343,Height=21}
                ...
                TimeSlotUIElement, Location = {X=67,Y=500,Width=343,Height=21}
                TimeSlotUIElement, Location = {X=67,Y=521,Width=343,Height=21}
        TimeSlotDescriptorAreaContainerUIElement, Location = {X=0,Y=58,Width=67,Height=484}
            TimeSlotDescriptorAreaUIElement, Location = {X=0,Y=58,Width=67,Height=484}
                TimeSlotDescriptorUIElement, Location = {X=0,Y=58,Width=67,Height=84} [Active]
                    HourUIElement, Location = {X=-14,Y=60,Width=58,Height=33}
                    MinuteUIElement, Location = {X=40,Y=59,Width=27,Height=20}
                ...
                TimeSlotDescriptorUIElement, Location = {X=0,Y=478,Width=67,Height=84}
                    HourUIElement, Location = {X=-14,Y=480,Width=58,Height=33}
                    MinuteUIElement, Location = {X=40,Y=479,Width=27,Height=20}
    ScrollBarUIElement, Location = {X=410,Y=0,Width=19,Height=542}
        ScrollArrowUIElement, Location = {X=410,Y=0,Width=19,Height=19}
        ScrollArrowUIElement, Location = {X=410,Y=523,Width=19,Height=19}
        ScrollTrackUIElement, Location = {X=410,Y=19,Width=19,Height=504}
            ScrollThumbUIElement, Location = {X=410,Y=187,Width=19,Height=121}
            ScrollTrackSubAreaUIElement, Location = {X=410,Y=19,Width=19,Height=168}
            ScrollTrackSubAreaUIElement, Location = {X=410,Y=308,Width=19,Height=215}
*/
